@@ -13,8 +13,8 @@ from tempfile import mkstemp, gettempdir
 from urllib.request import urlopen, Request
 from urllib.error import HTTPError
 
-OPENBLAS_V = '0.3.23'
-OPENBLAS_LONG = 'v0.3.23'
+OPENBLAS_V = '0.3.23.dev'
+OPENBLAS_LONG = 'v0.3.23-246-g3d31191b'
 BASE_LOC = 'https://anaconda.org/multibuild-wheels-staging/openblas-libs'
 BASEURL = f'{BASE_LOC}/{OPENBLAS_LONG}/download'
 SUPPORTED_PLATFORMS = [
